// CR x8 jcv 19-Jan-09 New plots for debugging
// SPRx22 jcv 4-Feb-2010 gcc4 migration
// SPRx31 jcv 24-Mar-2010 Added moveup function for new columns

#ifndef RTX_H
#define RTX_H

#include "Pass.h"

#include "Dal.h"
#include "STime.h"

#include <iostream>
#include <vector>
#include <map>

class RTX {

 public:

  int revolution;
  int version;
  STime start;
  STime end;

  stringstream logfile;

  //////////////////////////////////////
  // DATA SET (FITS FILE) POINTERS 

  DataSet *dataSet;

  Table *tab;

  // Column declarations
  //
  Column *frameCol;
  Column *obtcCol;
  Column *obtfCol;
  Column *utcdayCol;
  Column *utcmilCol;
  Column *utcmicCol;
  Column *utcflagCol;
  Column *ertCol;
  Column *gsidCol;
  Column *ertrawCol;
  Column *utcreaCol;
  Column *obtrCol;
  Column *passCol;
  Column *gsCol;
  Column *predERTCol;
  Column *residCol;

  // SPRx31 New columns
  Column *obtnofitCol;
  Column *utcnofitCol;
  // END SPRx31

  // Bare Data Column Declarations
  //
  ColumnData *frameColD;
  ColumnData *obtcColD;
  ColumnData *obtfColD;
  ColumnData *utcdayColD;
  ColumnData *utcmilColD;
  ColumnData *utcmicColD;
  ColumnData *utcflagColD;
  ColumnData *ertColD;
  ColumnData *gsidColD;
  ColumnData *ertrawColD;
  ColumnData *utcreaColD;
  ColumnData *obtrColD;
  ColumnData *passColD;
  ColumnData *gsColD;
  ColumnData *predERTColD;
  ColumnData *residColD;

  // SPRx31 New columns
  ColumnData *utcnofitColD;
  ColumnData *obtnofitColD;
  // END SPRx31

  // Numeric Data Declarations
  //
  int32  *frameData;
  int32  *obtcData;
  uint16 *obtfData;
  int16  *utcdayData;
  int32  *utcmilData;
  int16  *utcmicData;
  int16  *utcflagData;
  real64 *utcreaData;
  real64 *obtrData;
  int16  *passData;
  int16  *gsData;
  real64 *predERTData;
  real64 *residData;

  // SPRx31 New columns
  real64 *utcnofitData;
  real64 *obtnofitData;
  // END SPRx31
 
  //////////////////////////////////////
  // FUNCTIONS

  RTX(STime Start, STime End, int rev, int ver, int size);
  void close();
  void open(Dal::AccessMode mode = DataSet::Modify);

  Pass fitRevolution(bool ignoreBadPoints = false);

  // SPRx22 gcc4 migration
  //map<int, Pass *> RTX::fitPasses(bool ignoreBadPoints, bool fitEntirePass = false);
  map<int, Pass *> fitPasses(bool ignoreBadPoints, bool fitEntirePass = false);

  void predictERT(Pass fit);

  void plotRevolution(string title, string subtitle, string extension);

  // NEW CR x8
  void plotInputsRevolution(string title, string subtitle, string extension);

  void truncateFile();
  void cleanup();
  // NEW SPRx31
  void moveup();

  string getFilename(string extension);

};


#endif
