// CRx18b  jcv   10-Jul-09 Modifications from PacketConsumer

#ifndef STSPPROCESSOR_H
#define STSPPROCESSOR_H

#include <vector>
#include <iostream>
#include <fstream>

#include <Dal.h>

#include "DataDefinition.h"
#include "FrameConsumer.h"
#include "PacketConsumer.h"
#include "Pass.h"
#include "STSP.h"
#include "Delay.h"
#include "RTX.h"

class STSPProcessor : public FrameConsumer, public PacketConsumer {
  
public:
   
  virtual void processFrame(RawTM::NCTRS::TMDU &frm);
  
  virtual bool acceptFrame(RawTM::NCTRS::FrameHeader &hdr);
  
  virtual void processPacket(RawTM::XMM::Packet &pkt, STime &time);
  
  virtual bool acceptPacket(RawTM::XMM::PacketHeader &hdr, RawTM::XMM::DataFieldHeader &dfh);  

  // NEW CRx18b
  virtual bool hasTimePacket(RawTM::XMM::Packet &pkt); 
  virtual bool willacceptPacket(RawTM::XMM::PacketHeader &hdr, RawTM::XMM::DataFieldHeader &dfh, unsigned char rawSID);
  // END CRx18b

  void createRTX();
  
  void correctSTSPs(ostream & os);
  
  STSPProcessor(int rev, int ver);
  virtual ~STSPProcessor(){};

  STime Start;
  STime End;

 private:

  bool haveFrame;
  
  bool hasOBTreset;

  int Revolution;
  string revString;
  // CRx5 enhanced version management
  string verString;


  int Version;

  Delay delayHandler;

  int unwrapMFC(unsigned char mfc, Utils::CDSTime time);

  
  // Store current Frame
  RawTM::NCTRS::TMDU currentFrame;

  // The unwrapped MFC of the current Frame
  int MFC;
  
  // unwrapped MFC and Time of (VFC % 16 == 0) frame on VC0
  int   MFCVC0;
  STime TimeVC0;
  
  // Reference point for XMCS correction
  STime refXMCSCorrection;
  
  // List of packets to process
  vector<STSP> packetList;

  RTX *rtxFile;

};


#endif
