#!/bin/sh
#
export STSPHOME=/home/tcxgen/tm
export STSPBIN=/home/tcxgen/tmproc

thisRev=$1

mkdir -p $STSPHOME/new
mkdir -p $STSPHOME/spare
mkdir -p $STSPHOME/error
mkdir -p $STSPHOME/warning
mkdir -p $STSPHOME/processed/data
mkdir -p $STSPHOME/processed/ps
mkdir -p $STSPHOME/processed/log
mkdir -p $STSPHOME/processed/stsp

#
# Set up SAS Paths
OLDPATH=$PATH
export SAS_DIR=/xdata/sas/Linux/RedHat9/xmmsas_20070708_1801
export SAS_PATH=$STSPBIN:$SAS_DIR
. $SAS_DIR/sas-setup.sh
export PATH=$PATH:$OLDPATH

cd $STSPHOME

#
# Get the orbita file from the website  
wget -q http://xmm.vilspa.esa.es/~xmmdoc/orbit/data/orbita.tar.gz -O $STSPHOME/fds/orbita.tar.gz

#
# Untar it
tar zxf $STSPHOME/fds/orbita.tar.gz  -C $STSPHOME/fds

#
# Get the Revolution number from the website
wget -q http://xmm.vilspa.esa.es/~xmmdoc/orbit/data/revno -O $STSPHOME/fds/revno

#
# Format it into the required form
grep "START REVOLUTION" $STSPHOME/fds/revno | awk '{print $7,$4}' > $STSPHOME/revno.txt

#
# Move newly created files to new directory
if [ -f $STSPHOME/RTX_* ]; then
    mv -f $STSPHOME/RTX_* $STSPHOME/spare/
fi

#
# Move any remnant from previous runs to processed directory
if [ -f  $STSPHOME/new/* ]; then
    mv -f $STSPHOME/new/* $STSPHOME/spare/
fi

echo "Running stspproc for Revolution $thisRev"

#
# Run the task
stspproc --revolution=$thisRev --useS2K=yes > $STSPHOME/new/$thisrev_genstsp.log 2>&1

#
# Move newly created files to new directory
mv -f $STSPHOME/RTX_* $STSPHOME/new/

#
# Look for errors
nErrors=`grep ERROR $STSPHOME/new/RTX_*log | wc -l`

if (( $nErrors != 0)); then

    echo "stspproc failed for Revolution" $thisrev
    cat $STSPHOME/new/*.log
    mv -f $STSPHOME/new/* $STSPHOME/error/

else

    nWarnings=`grep WARNING $STSPHOME/new/RTX_*log | wc -l`

    if (( $nWarnings != 0)); then

	echo "stspproc completed with warnings for Revolution" $thisrev
	cat $STSPHOME/new/*.log
	mv -f $STSPHOME/new/* $STSPHOME/warning/

    else

	echo "stspproc completed successfully for Revolution " $thisrev
	mv -f $STSPHOME/new/RTX*FIT  $STSPHOME/processed/data/
	mv -f $STSPHOME/new/RTX*ps   $STSPHOME/processed/ps/
	mv -f $STSPHOME/new/RTX*log  $STSPHOME/processed/log/
        mv -f $STSPHOME/new/RTX*stsp $STSPHOME/processed/stsp/


    fi

fi


