// SPRx22 jcv 4-Feb-2010 gcc4 migration

#include <iostream>

#include "tcscheck.h"
#include "TCS.h"
#include "CalOalUtility.h"
#include "Utils.h"
#include "STime.h"

inline double convertToDouble(const std::string& s);

///////////////////////
//
//
//
//
void tcscheck () {
  
  string infile = stringParameter("file");

  int revno = atoi(infile.substr(0,4).c_str());
  int obsid = atoi(infile.substr(5,10).c_str());

  TCS tcsfile(TCSfiles::TCS, revno, obsid);
  TCS rtxfile(TCSfiles::TCX, revno, obsid);

  int TCSfirstRow = 0;
  int TCSlastRow = tcsfile.tab->rows() - 1;
  int TCSnRows = tcsfile.tab->rows();

  int TCSstartOBTC = tcsfile.obtcData[TCSfirstRow];
  int TCSstartOBTF = tcsfile.obtfData[TCSfirstRow];
  int TCSendOBTC   = tcsfile.obtcData[TCSlastRow];
  int TCSendOBTF   = tcsfile.obtfData[TCSlastRow];

  STime TCSstartERT(CalOalUtility::stringColumnRow(tcsfile.ertColD, TCSfirstRow));
  STime TCSendERT(CalOalUtility::stringColumnRow(tcsfile.ertColD, TCSlastRow));

  std::cout << "TCS rows: " 
	    << TCSstartOBTC << "." << TCSstartOBTF 
	    << " (" 
	    << TCSstartERT.toString(6)
	    << ")"
	    << " -> " 
	    << TCSendOBTC << "." << TCSendOBTF 
	    << " (" 
	    << TCSendERT.toString(6)
	    << ") "
	    << "Rows: " 
	    << TCSnRows
	    << std::endl;

  int RTXfirstRow = -1;
  int RTXlastRow = -1;
  int RTXnRows = 0;

  // Find the rows in the RTX file
  for (unsigned int i = 0; i < rtxfile.tab->rows(); i++) {

    if ((rtxfile.obtcData[i] == TCSstartOBTC) && 
	(rtxfile.obtfData[i] == TCSstartOBTF)) {
      RTXfirstRow = i;
    }

    if ((rtxfile.obtcData[i] == TCSendOBTC) && 
	(rtxfile.obtfData[i] == TCSendOBTF)) {
      RTXlastRow = i;
    }

  }

  if (RTXfirstRow == -1) {

    std::cout << "Start row not found in RTX" << std::endl;
    return;

  }
  
  if (RTXlastRow == -1) {

    std::cout << "End row not found in RTX" << std::endl;
    return;

  }

  RTXnRows =  RTXlastRow - RTXfirstRow;
  
  std::cout << "RTX rows: " 
	    << RTXfirstRow 
	    << " -> " 
	    << RTXlastRow
	    << " Rows: "
	    << RTXnRows + 1 
	    << std::endl;

  
  unsigned int RTXrowCounter = RTXfirstRow;
  double delta;
  // SPRX22 gcc4 migration avoid exceed on range double
  //double minDelta = 1.0e999;
  //double maxDelta = -1.0e999;
  double minDelta = 1.0e99;
  double maxDelta = -1.0e99;
  double sumDeltas = 0.0;
  int nRecords = 0;

  for (unsigned int i = 0; i < tcsfile.tab->rows(); i++, RTXrowCounter++) {

    int TCSOBTC = tcsfile.obtcData[i];
    int TCSOBTF = tcsfile.obtfData[i];
    STime TCSERT(CalOalUtility::stringColumnRow(tcsfile.ertColD, i));
    STime TCSRAWERT(CalOalUtility::stringColumnRow(tcsfile.ertrawColD, i));
	double TCSCORRPARA = convertToDouble(CalOalUtility::stringColumnRow(tcsfile.corrparaColD, i));
	double TCSCORRPARB = convertToDouble(CalOalUtility::stringColumnRow(tcsfile.corrparbColD, i));
 
    int RTXOBTC = rtxfile.obtcData[RTXrowCounter];
    int RTXOBTF = rtxfile.obtfData[RTXrowCounter];
    double OBT = (double)RTXOBTC + (double)RTXOBTF / 65536.0; 
    STime RTXERT(CalOalUtility::stringColumnRow(rtxfile.ertColD, RTXrowCounter));
    string RTXgsid(CalOalUtility::stringColumnRow(rtxfile.gsidColD, RTXrowCounter));
    int RTXflag = rtxfile.utcflagData[RTXrowCounter];
    STime RTXRAWERT(CalOalUtility::stringColumnRow(rtxfile.ertrawColD, RTXrowCounter));
	double RTXCORRPARA = convertToDouble(CalOalUtility::stringColumnRow(rtxfile.corrparaColD, RTXrowCounter));
	double RTXCORRPARB = convertToDouble(CalOalUtility::stringColumnRow(rtxfile.corrparbColD, RTXrowCounter));

    if ((TCSOBTC == RTXOBTC) && (TCSOBTF == RTXOBTF)) {

      if (!RTXflag) {

	delta = TCSERT - RTXERT;
	sumDeltas += delta;
	
	nRecords++;
	
	if (delta < minDelta) {
	  minDelta = delta;
	}
	
	if (delta > maxDelta) {
	  maxDelta = delta;
	}

        std::cout.precision(16);
	std::cout 
		<< "GS: "
		<< RTXgsid 
		<< " OBT: "
		<< OBT
		<< " RawERT: " 
		<< RTXRAWERT.modifiedJulianDay().full()
		<< " TCS: "
		<< TCSERT.toString(6) 
		<< " TCX: " 
		<< RTXERT.toString(6) 
		<< " diff: "
		<< TCSERT - RTXERT
		<< " rawdiff: "
		<< TCSRAWERT - RTXRAWERT
		<< " slopediff: "
		<< TCSCORRPARA - RTXCORRPARA
		<< " interdiff: "
		<< TCSCORRPARB - RTXCORRPARB
		<< std::endl; 
      }
      else {

	std::cout << "Ignoring record marked as bad @ "
		  << "GS: "
		  << RTXgsid 
		  << " TCS: "
		  << TCSERT.toString(6) 
		  << " TCX: " 
		  << RTXERT.toString(6) 
		  << " diff: "
		  << TCSERT - RTXERT
		  << std::endl; 
      }

    }
    else {

      std::cout << "No Result for " << infile << ": Missing TM. To be fixed" << std::endl;
      break;

    }

  }

  std::cout << "Result for "
	    << infile
	    << " Min: " 
	    << minDelta
	    << " Max: "
	    << maxDelta
	    << " Avg: "
	    << sumDeltas/nRecords 
	    << std::endl; 

}

inline double convertToDouble(const std::string& s)
{
	std::istringstream i(s);

	double x;
	
	i >> x;	

	return x;

} 
