// SPRx29  jcv 19-Feb-2010 Fix of old TCXs files 
// SPRx29b jcv 10-Mar-2010 Added final columns arrangements (mymove)

#include <iostream>

#include "tcxfix.h"

#include "FIX.h"
#include "CalOalUtility.h"
#include "Utils.h"
#include "STime.h"

///////////////////////
//
//
//
//
void tcxfix () {

  stringstream streamVerFile, streamIncreasedVer,streamFile;
  stringstream streamFinalName;

  //streamVerFile.width(3); streamVerFile.fill('0');

  string sFile,sVer;
  int iVer;
 
  // Get the filename from parameter  
  string infile = stringParameter("file");
  // Get the version to write within
  string sTCXVersion = stringParameter("version");
  // Get the boolean for increasing version
  bool bIncreaseVersion = booleanParameter("increasever");

  // Read the file
  std::cout << "Tcxfix tool has started to process " << infile << std::endl;
  std::cout << "...will set TCXVER to  " << sTCXVersion << std::endl;

  // Set the file creator name
  dataSetServer->client( "tcxfix" );

  // OPEN the file to Modify
  tcxSet = dataSetServer->open( infile, DataSet::Modify );

  ///////////////////////////////////////////////
  // KEYWORDS MODIFICATIONS

  if ( tcxSet->hasAttribute("TCXVER")) {

    errstr << "TCXVER keyword found. Updating" << Sas::warning("updTCXVER");
    tcxSet->deleteAttribute("TCXVER");

  } else {

    errstr << "TCXVER keyword not found. Inserting" << Sas::warning("NoTCXVER");
  } 

  // Some cheks on VERSION about if has proper attributes
  if ( tcxSet->hasAttribute("VERSION")) {

      streamVerFile << tcxSet->attribute("VERSION")->asString();
      streamVerFile >> iVer;
      tcxSet->deleteAttribute("VERSION");

      if (bIncreaseVersion) {
          // Requested to increase the version
          errstr << "VERSION keyword read as " << iVer << " to be increased" 
            <<  Sas::warning("incrVER");
          iVer++; 

          // Some operations over FILENAME keyword
          if ( tcxSet->hasAttribute("FILENAME")) {
             streamFile << tcxSet->attribute("FILENAME")->asString();
             sFile = streamFile.str();
             tcxSet->deleteAttribute("FILENAME");

          } else {
              std::cout << "FILENAME keyword not found. Aborted" << std::endl;
              errstr << "FILENAME key not found" << Sas::error("noFILENAME");
          }

         // End requested to increase the version

      } else {
          // The version will remain as is
          errstr << "VERSION keyword read as " << iVer << " to be kept as is" 
            <<  Sas::warning("leaveVER");
      }

  } else {
    // The VERSION keyword was not found
    std::cout << "VERSION keyword not found. Aborted." << std::endl;
    errstr << "VERSION keyword not found." << Sas::error("noVERSION");
  }


  // Update the keywords

  // Now write the proper VERSION version
  streamIncreasedVer.width(3); streamIncreasedVer.fill('0');
  streamIncreasedVer << iVer;
  sVer = streamIncreasedVer.str();
  * tcxSet->addAttribute("VERSION","Version of this datafile")=sVer; 

  // Now write the proper FILENAME keyword
  if (bIncreaseVersion) {
      streamFinalName.width(4); streamFinalName.fill('0');
      streamFinalName << iVer;
      sVer = streamFinalName.str();
      sFile.replace(9,4,sVer);
      * tcxSet->addAttribute("FILENAME","Filename")=sFile; 
  }

  // Now write the proper TCXVER version
  * tcxSet->addAttribute("TCXVER","Version of TCX production software")=sTCXVersion;

  errstr << "Writen TCXVER as " << sTCXVersion 
        << " VERSION as " << iVer 
        << " FILENAME as " << sFile
        << Sas::message(Msg::App, Msg::Verbose);

  ///////////////////////////////////////////////
  // DATA MODIFICATIONS

  // Now just read the columns and overwrite them
  myopen(); 
  mymove();
  mycleanup();
  myclose();

  std::cout << "Tcxfix tool ended " <<  std::endl;

}

void myopen() {

  tab     = tcxSet->table("SCRTX1");

  //////////////////
  // Read columns
  frameCol   = tab->column("FRAME");
  utcdayCol  = tab->column("UTCDAY");
  utcmilCol  = tab->column("UTCMILLI");
  utcmicCol  = tab->column("UTCMICRO");
  utcflagCol = tab->column("UTCFLAG");
  ertCol     = tab->column("ERTIME");
  gsidCol    = tab->column("GSID");
  ertrawCol  = tab->column("ERTIMRAW");

  // The new columns

  if (tab->hasColumn("UTCREAL")) {

    utcreaCol  = tab->column("UTCREAL");
    obtrCol    = tab->column("OBTREAL");
    passCol    = tab->column("PASS");
    gsCol      = tab->column("GS");
    predERTCol = tab->column("PREDUTC");
    residCol   = tab->column("RESIDUAL");

  } else {

    std::cout << "UTCREAL not found. May be FIX not needed." << std::endl;
    errstr << "UTCREAL data not found." << Sas::error("noUTCReal");

  }

  /////////////////////////
  // Get the column data
  frameColD   = frameCol->data();
  utcdayColD  = utcdayCol->data();
  utcmilColD  = utcmilCol->data();
  utcmicColD  = utcmicCol->data();
  utcflagColD = utcflagCol->data();
  ertColD     = ertCol->data();
  ertrawColD  = ertrawCol->data();

  // The new data
  utcreaColD  = utcreaCol->data();
  obtrColD    = obtrCol->data();
  passColD    = passCol->data();
  gsColD      = gsCol->data();
  predERTColD = predERTCol->data();
  residColD   = residCol->data();

  ///////////////////////////
  // Get pointers to the data
  frameData   = frameColD->int32Data();
  utcdayData  = utcdayColD->int16Data();
  utcmilData  = utcmilColD->int32Data();
  utcmicData  = utcmicColD->int16Data();
  utcflagData = utcflagColD->int16Data();
  // gs???

  // The new pointers 
  utcreaData  = utcreaColD->real64Data();
  obtrData    = obtrColD->real64Data();
  // gs???
  predERTData = predERTColD->real64Data();
  residData   = residColD->real64Data();

}

void myclose() {

  // Close the dataset  
  dataSetServer->close(tcxSet);

  // Go through and release memory

}

void mymove() {

  unsigned int i;
  Utils::CDSTime cdsT;
  STime old_ert;

  std::cout << "Tcxfix creating new nofit columns  " << std::endl;

  // Add two new columns for containing no fitted data
  tab->addColumn("UTCNOFIT", Column::Real64, "UTC nofitted", "        ");
  tab->addColumn("OBTNOFIT", Column::Real64, "OBT nofitted", "        ");

  // Create pointer to new columns
  obtnofitCol = tab->column("OBTNOFIT");
  utcnofitCol =  tab->column("UTCNOFIT");

  // Get the columns data
  utcnofitColD  = utcnofitCol->data();
  obtnofitColD   = obtnofitCol->data();

  // Get pointers to the data
  utcnofitData  = utcnofitColD->real64Data();
  obtnofitData  = obtnofitColD->real64Data();

  for (i = 0; i < tab->rows(); i++) {
    // First Movement: OBTCoarse and Fine to obtnofit
    //obtnofitData[i]=obtcData[i]+obtfData[i]/65535.0;
    obtnofitData[i]=obtrData[i];
      
    // Second Movement: UTCday/micro/milli to UTCnofit
    cdsT.Days = utcdayData[i];
    cdsT.Milliseconds = utcmilData[i];
    cdsT.Microseconds = utcmicData[i];
    old_ert = Utils::cds2STime(cdsT);
    utcnofitData[i]=Utils::STime2MJD2000(old_ert) * 86400.0;
    // Or alternatively, string ERTime to UTCnofit
    //CalOalUtility::stringColumnRowSet(utcnofitColD, currentRow,old_ert.toString(6));

  }
 

}

void mycleanup() {

  unsigned int i;

  for (i = 0; i < tab->rows(); i++) {

    // Update the frame counter
    frameData[i] = i + 1;

    // Get the UTC fitted time
    STime entry = Utils::MJD20002STime(utcreaData[i] / 86400.0);

    // FIRST UPDATE
    // Update the ERT field
    CalOalUtility::stringColumnRowSet(ertColD, i, entry.toString(6));

    // SECOND UPDATE
    // Update the UTC fields
    Utils::CDSTime cdsT = Utils::STime2cds(entry);
    utcdayData[i] = cdsT.Days;
    utcmilData[i] = cdsT.Milliseconds;
    utcmicData[i] = cdsT.Microseconds;
  }

  // Delete the old columns
  tab->deleteColumn("UTCREAL");
  tab->deleteColumn("OBTREAL");
  tab->deleteColumn("PASS");
  tab->deleteColumn("GS");
  tab->deleteColumn("PREDUTC");
  tab->deleteColumn("RESIDUAL");

}

