// SPR x1 jcv 8-Oct-08 tmcheck args re-typing
// SPR x6 jcv 16-Dec-08 more logging info 
// CRx12 jcv 1-Apr-09 Process DU refactored
// CRx13 jcv 1-Apr-09 Able to force reading one single file
// SPRx11 jcv 2-Apr-09 Packet processing depends on verbosity

#include <iostream>
#include <sstream>
#include <fstream>

#include <vector>

#include "DUExtractor.h"
#include "NCTRSProcessor.h"
#include "PacketProcessor.h"
#include "STSPProcessor.h"

#include "tmcheck.h"
#include "Revolution.h"

#include "errstr.h"
#include "ExceptionErrorHandler.h"

///////////////////////
//
//
//
//
void tmcheck () {

  // SPR x1 Args re-typed  
  //double start = realParameter("start");
  //double end = realParameter("end");
  STime start = stringParameter("StartTime");
  STime end = stringParameter("EndTime");
  bool bS2K = booleanParameter("useS2K");
  string sCacheDir = stringParameter("cachedir");

  bool bStrictRun=booleanParameter("strict");
  if(  bStrictRun )
    errstr << "Strict=yes Running in normal mode" << Sas::warning("Strict_yes");
  else
    errstr << "Strict=no WARNING Running in non-abort mode" << Sas::warning("Strict_no");

  // SPR x6
  errstr << "S2K boolean is (1=TRUE 0=FALSE): " << bS2K << Sas::message(Msg::App, Msg::Verbose);
  errstr << "TM cache:" << sCacheDir << Sas::message(Msg::App, Msg::Verbose);

  // NEW CRx13
  string sRawFile = stringParameter("rawfile");
  string sFullName;
  FILE * pRawFile;
  int maxDUsize;
  bool bDummie;

  // For Frames checking this is the only thing needed
  DUExtractor myExtractor( start, end );

  // For packet checking, this is also needed
  //if(errHandler.verbosity(Msg::App) >= Msg::Verbose ) {
    STSPProcessor proc = STSPProcessor(0,0);
    proc.Start = start;
    proc.End   = end;
    NCTRSProcessor * myNCTRSProcessor = new NCTRSProcessor(&proc, NCTRSProcessor::VC0);
    PacketProcessor * myPacketProcessor = new PacketProcessor(&proc);
    myExtractor.registerProcessor(myNCTRSProcessor);
    myNCTRSProcessor->registerProcessor(myPacketProcessor);
  //}

  // We compare against the default value found in tmcheck.par 
  if ( sRawFile.compare("none") != 0 ) {
    errstr << "Forced to read " << sRawFile << Sas::message(Msg::App, Msg::Verbose);
    sFullName = sCacheDir;
    sFullName.append("/");
    sFullName.append(sRawFile);

    errstr << "Full filename to read " << sFullName << Sas::message(Msg::App, Msg::Verbose);

    if ((pRawFile = fopen(sFullName.c_str(),"r")) == NULL) {
      errstr << "Failed to open data file " << sFullName 
             << Sas::fatal("failOpenDatafile");
    }
    // Read DUs by opening just the requested file
    myExtractor.processDU(pRawFile,&maxDUsize,&bDummie,bStrictRun);
    fclose(pRawFile);
    errstr << "Biggest DU found " << dec << maxDUsize << Sas::message(Msg::App, Msg::Sparse);

  }   
  else {
    errstr << "All the files embracing given start-stop times will be read " << Sas::message(Msg::App, Msg::Verbose);
    // Read DUs by opening all files covering requested time span
    myExtractor.loopDU();
  }
  // END CRx13

}
